# LicensedFeature

A feature of the system 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | [**LicensedFeatureName**](LicensedFeatureName.md) |  | 
**license_constraints** | [**[LicenseConstraint]**](LicenseConstraint.md) | Feature level constraints. Typically describe generic constraints that would apply to all products with this feature (e.g. a maximum)  | 
**constraint_variables** | [**LicenseConstraintVariables**](LicenseConstraintVariables.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


